package timestamps;

import timestamps.shared.MacroOption;

/**Macro options*/
public enum Option implements MacroOption<Option> {

   BREAKS("breaks", "Breaks", Integer.TYPE,
         "Outlier test of intervals (e.g., in FRAP experiments)"),
   REPORT("report", "Report", Report.class,
         "Generates a results table"),
   CHANNEL("channel", "Channel", Integer.TYPE,
         "The channel to be reported"),
   SLICE("slice", "Slice", Integer.TYPE,
         "The slice to be reported"),
   DISPLAY("display", "Display table", Boolean.TYPE,
         "Displays the report"),
   AUTOSAVE("autosave", "Autosave table", Boolean.TYPE,
         "Automatically saves the report"),
   OVERLAY("overlay", "Add to overlay", Boolean.TYPE,
         "Adds timestamps as non-destructive overlay to the image");

   private final String command, label, description;
   private final Class<?> parameterClass;

   /**Constructor.
    * @param command macro-recordable command
    * @param label short text as label for UI controls
    * @param parameterClass type of the parameter
    * @param description to be used as tooltip text*/
   Option(String command, String label, Class<?> parameterClass, String description) {
      this.command = command;
      this.label = label;
      this.description = description;
      this.parameterClass = parameterClass;
   }

   /**{@inheritDoc}*/
   @Override
   public String getCommand() {
      return command;
   }

   /**{@inheritDoc}*/
   @Override
   public String getLabel() {
      return label;
   }

   /**{@inheritDoc}*/
   @Override
   public Class<?> getParameterClass() {
      return parameterClass;
   }

   /**{@inheritDoc}*/
   @Override
   public String getDescription() {
      return description;
   }
}
