package timestamps;

import timestamps.shared.MacroOption;

/**Options for the results table (mutually exclusive)*/
enum Report implements MacroOption<Report> {

   FRAME("frame", "Each frame", null,
         "One timestamp per frame"),
   CHANNEL("channel", "Each channel", null,
         "Timestamps for each channel"),
   SLICE("slice", "Each slice", null,
         "Timestamps for each z slice"),
   ALL("all", "All images", null,
         "Timestamps of all channels/slices");

   private final String command, label, description;
   private final Class<?> parameterClass;

   /**Constructor.
    * @param command macro-recordable argument
    * @param label for UI elements
    * @param parameterClass unused in this implementation
    * @param description tooltips for UI elements*/
   Report(String command, String label, Class<?> parameterClass, String description) {
      this.command = command;
      this.label = label;
      this.parameterClass = parameterClass;
      this.description = description;
   }

   /**{@inheritDoc}*/
   @Override
   public String getCommand() {
      return command;
   }

   /**{@inheritDoc}*/
   @Override
   public String getLabel() {
      return label;
   }

   /**{@inheritDoc}*/
   @Override
   public Class<?> getParameterClass() {
      return parameterClass;
   }

   /**{@inheritDoc}*/
   public String getDescription() {
      return description;
   }

   /**Returns the label, avoiding renderers in UI elements to display enums in lists or combo boxes*/
   @Override
   public String toString() {
      return label;
   }
}
